@@ -27,6 +27,17 @@
   #define SSIZE_MAX LLONG_MAX
 #endif
 
+#ifdef WIN32
+  #include <windows.h>
+#else
+  #include <sys/mman.h>
+  #include <sys/stat.h>
+  #include <sys/types.h>
+  #include <fcntl.h>
+  #include <unistd.h>
+  #include <errno.h>
+#endif
+
 #define UTYPEOF(x) ((unsigned)TYPEOF(x))
 #define IS_BOOL(x) (LENGTH(x)==1 && TYPEOF(x)==LGLSXP && LOGICAL(x)[0]!=NA_LOGICAL)
 #define IS_VALID_TYPE(x) ((x) == LGLSXP || (x)==INTSXP || (x)==REALSXP || (x)==CPLXSXP || (x)==STRSXP || (x)==VECSXP)
@@ -53,7 +64,8 @@
 #define IS_LOGICAL(x) (isLogical(x) && LENGTH(x)==1)
 
 extern SEXP addColToDataFrame(SEXP df, SEXP mcol, SEXP coln);
-extern SEXP charToFactR(SEXP x, SEXP decreasingArg, SEXP nthread, SEXP nalast, SEXP env);
+extern SEXP callToOrder (SEXP x, const char* method, bool desc, Rboolean na, SEXP env);
+extern SEXP charToFactR(SEXP x, SEXP decreasingArg, SEXP nthread, SEXP nalast, SEXP env, SEXP addNA);
 extern SEXP countR(SEXP x, SEXP y);
 extern SEXP countNAR(SEXP x);
 extern SEXP countOccurR(SEXP x);
@@ -88,9 +100,13 @@ extern SEXP subSetColDataFrame(SEXP df, SEXP str);
 extern SEXP subSetColMatrix(SEXP x, R_xlen_t idx);
 extern SEXP subSetRowDataFrame(SEXP df, SEXP rws);
 extern SEXP subSetRowMatrix(SEXP mat, SEXP rws);
-extern SEXP topnR(SEXP vec, SEXP n, SEXP dec, SEXP hasna);
+extern SEXP topnR(SEXP vec, SEXP n, SEXP dec, SEXP hasna, SEXP env);
 extern SEXP vswitchR(SEXP x, SEXP values, SEXP outputs, SEXP na, SEXP nthreads, SEXP chkenc);
 
+extern SEXP createMappingObjectR(SEXP MapName, SEXP MapLength, SEXP DataObject, SEXP verboseArg);
+extern SEXP getMappingObjectR(SEXP MapName, SEXP MapLength, SEXP verboseArg);
+extern SEXP clearMappingObjectR(SEXP ext, SEXP verboseArg);
+
 union uno { double d; unsigned int u[2]; };
 bool isMixEnc(SEXP x);
 SEXP enc2UTF8(SEXP x);
